@@ -392,19 +392,42 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 	gtk_builder_connect_signals( builder, NULL);
 	//  we do it all mostly ourself, except for some delete-event binding to gtk_true()
 
-      // iterate all of AghHH, mark our channels
+      // add channels, EEGs first, then EOG, EMG, then the rest
 	size_t y = interchannel_gap / 2.;
-	for ( auto &H : _p.AghHH ) {
-		snprintf_buf( "Reading and processing channel %s ...", H.c_str());
-		_p.buf_on_status_bar();
-		try {
-			channels.emplace_back( _sepisode.recordings.at(H),
-					       *this, y);
+	for ( auto &H : _sepisode.recordings )
+		if ( H.second.signal_type() == sigfile::SChannel::TType::eeg ) {
+			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
+			_p.buf_on_status_bar();
+			channels.emplace_back( H.second, *this, y);
+			y += interchannel_gap;
+		}
+	for ( auto &H : _sepisode.recordings )
+		if ( H.second.signal_type() == sigfile::SChannel::TType::eog ) {
+			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
+			_p.buf_on_status_bar();
+			channels.emplace_back( H.second, *this, y);
+			y += interchannel_gap;
+		}
+	for ( auto &H : _sepisode.recordings )
+		if ( H.second.signal_type() == sigfile::SChannel::TType::emg ) {
+			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
+			_p.buf_on_status_bar();
+			channels.emplace_back( H.second, *this, y);
+			y += interchannel_gap;
+		}
+	for ( auto &H : _sepisode.recordings ) {
+		auto type = H.second.signal_type();
+		if ( type != sigfile::SChannel::TType::eeg &&
+		     type != sigfile::SChannel::TType::eog &&
+		     type != sigfile::SChannel::TType::emg ) {
+			snprintf_buf( "Reading and processing channel %s ...", H.first.c_str());
+			_p.buf_on_status_bar();
+			channels.emplace_back( H.second, *this, y);
 			y += interchannel_gap;
-		} catch (...) {
-			fprintf( stderr, "SScoringFacility::SScoringFacility(): no such channel: %s\n", H.c_str());
 		}
 	}
+	if ( channels.size() == 0 )
+		throw invalid_argument( string ("No channels found for combination (") + J.name() + ", " + D + ", " + E + ")");
 	da_ht = montage_est_height();
 
       // load montage
@@ -424,8 +447,9 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 					      >> h.draw_zeroline
 					      >> h.draw_original_signal
 					      >> h.draw_filtered_signal
-					      >> h.draw_power >> h.draw_bands >> h.draw_spectrum_absolute
+					      >> h.draw_power >> h.draw_bands
 					      >> h.resample_signal
+					      >> h.resample_power
 					      >> h.zeroy
 					      >> h.selection_start_time >> h.selection_end_time
 					      >> h.signal_display_scale >> h.power_display_scale >> h.emg_scale;
@@ -436,9 +460,6 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 	}
 	// sane values, now set, will be used in SChannel ctors
 
-	if ( channels.size() == 0 )
-		throw invalid_argument( string ("No channels found for combination (") + J.name() + ", " + D + ", " + E + ")");
-
       // histogram -> scores
 	get_hypnogram();
 	calculate_scored_percent();
@@ -586,8 +607,9 @@ aghui::SScoringFacility::~SScoringFacility()
 				ofs << H.hidden << ' '
 				    << H.draw_zeroline << ' ' << H.draw_original_signal << ' '
 				    << H.draw_filtered_signal << ' '
-				    << H.draw_power << ' ' << H.draw_bands << ' ' << H.draw_spectrum_absolute << ' '
+				    << H.draw_power << ' ' << H.draw_bands << ' '
 				    << H.resample_signal << ' '
+				    << H.resample_power << ' '
 				    << H.zeroy << ' '
 				    << H.selection_start_time << ' ' << H.selection_end_time << ' '
 				    << H.signal_display_scale << ' ' << H.power_display_scale << ' ' << H.emg_scale << ' ' << endl;
